**Example 1: 示例1**

demo

Input: 

```
tccli wedata RenewWorkflowFolderDs --cli-unfold-argument  \
    --ProjectId 1460947878944567296 \
    --WorkflowId e5b0945c-ed6d-11ed-8909-bc97e105ba60 \
    --FolderId 12800b85-ed6f-11ed-8909-bc97e105ba60
```

Output: 
```
{
    "Response": {
        "Data": true,
        "RequestId": "b5873c91-b5ab-4f6e-9075-6b8f5731e71c"
    }
}
```

